import { ElementRef, EventEmitter, OnInit } from "@angular/core";
import { ControlValueAccessor } from "@angular/forms";
import { ICalendarDate, WEEKDAYS } from "./calendar";
export declare enum CalendarView {
    DEFAULT = 0,
    YEAR = 1,
    DECADE = 2,
}
/**
 *
 *
 * @export
 * @class IgxCalendarComponent
 * @implements {OnInit}
 * @implements {DoCheck}
 * @implements {ControlValueAccessor}
 */
export declare class IgxCalendarComponent implements OnInit, ControlValueAccessor {
    private elementRef;
    /**
     * Returns the day on which the week starts
     *
     * @readonly
     * @type {(WEEKDAYS | number)}
     * @memberof IgxCalendarComponent
     */
    weekStart: WEEKDAYS | number;
    locale: string;
    selection: string;
    viewDate: Date;
    onSelection: EventEmitter<Date | Date[]>;
    value: Date | Date[];
    formatOptions: {
        day: string;
        month: string;
        weekday: string;
        year: string;
    };
    readonly activeView: CalendarView;
    readonly monthAction: string;
    private calendarModel;
    private _viewDate;
    private headerDate;
    private _activeView;
    private selectedDates;
    private _selection;
    private _rangeStarted;
    private _monthAction;
    constructor(elementRef: ElementRef);
    registerOnChange(fn: (_: Date) => void): void;
    registerOnTouched(fn: () => void): void;
    writeValue(value: Date | Date[]): void;
    ngOnInit(): void;
    generateWeekHeader(): string[];
    readonly getCalendarMonth: ICalendarDate[][];
    onDateClick(event: MouseEvent): void;
    selectDate(date: Date | Date[]): void;
    handleKeyDown(event: any): void;
    selectSingle(newVal: Date): void;
    selectMulti(newVal: Date | Date[]): void;
    selectRange(newVal: Date | Date[]): void;
    prevMonth(): void;
    nextMonth(): void;
    handleScroll(event: any): void;
    handlePageUpDown(event: any): void;
    handleKeyboardNavigation(event: any): void;
    getMonthName(date: Date): string;
    getFormattedDate(): {
        weekday: string;
        monthday: string;
    };
    getHeaderYear(): string;
    isInactive(day: ICalendarDate): boolean;
    isWeekend(day: ICalendarDate): boolean;
    isCurrentMonth(value: Date): boolean;
    isCurrentYear(value: number): boolean;
    isSelected(day: ICalendarDate): boolean;
    isToday(day: ICalendarDate): boolean;
    readonly isDefaultView: boolean;
    readonly isYearView: boolean;
    readonly isDecadeView: boolean;
    activeViewYear(): void;
    activeViewDecade(): void;
    getDecade(): number[];
    getYear(): Date[];
    changeYear(event: any): void;
    changeMonth(event: any): void;
    dateTracker(index: any, item: any): string;
    rowTracker(index: any, item: any): string;
    monthTracker(index: any, item: any): number;
    private _onTouchedCallback;
    private _onChangeCallback;
}
export declare class IgxCalendarModule {
}
