import { transition, trigger, useAnimation } from "@angular/animations";
import { CommonModule } from "@angular/common";
import { Component, ElementRef, EventEmitter, Input, NgModule, Output } from "@angular/core";
import { FormsModule, NG_VALUE_ACCESSOR } from "@angular/forms";
import { BrowserAnimationsModule } from "@angular/platform-browser/animations";
import { fadeIn, scaleInCenter, slideInLeft, slideInRight } from "../animations/main";
import { IgxIconModule } from "../icon/icon.component";
import { Calendar, range } from "./calendar";
export var CalendarView;
(function (CalendarView) {
    CalendarView[CalendarView["DEFAULT"] = 0] = "DEFAULT";
    CalendarView[CalendarView["YEAR"] = 1] = "YEAR";
    CalendarView[CalendarView["DECADE"] = 2] = "DECADE";
})(CalendarView || (CalendarView = {}));
/**
 *
 *
 * @export
 * @class IgxCalendarComponent
 * @implements {OnInit}
 * @implements {DoCheck}
 * @implements {ControlValueAccessor}
 */
var IgxCalendarComponent = /** @class */ (function () {
    function IgxCalendarComponent(elementRef) {
        this.elementRef = elementRef;
        this.locale = "en";
        this.onSelection = new EventEmitter();
        this.formatOptions = {
            day: "numeric",
            month: "short",
            weekday: "short",
            year: "numeric"
        };
        this._activeView = CalendarView.DEFAULT;
        this._selection = "single";
        this._rangeStarted = false;
        this._monthAction = "";
        this._onTouchedCallback = function () { };
        this._onChangeCallback = function () { };
        this.calendarModel = new Calendar();
    }
    Object.defineProperty(IgxCalendarComponent.prototype, "weekStart", {
        get: /**
             * Returns the day on which the week starts
             *
             * @readonly
             * @type {(WEEKDAYS | number)}
             * @memberof IgxCalendarComponent
             */
        function () {
            return this.calendarModel.firstWeekDay;
        },
        set: function (value) {
            this.calendarModel.firstWeekDay = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "selection", {
        get: function () {
            return this._selection;
        },
        set: function (value) {
            switch (value) {
                case "single":
                    this.selectedDates = null;
                    break;
                case "multi":
                case "range":
                    this.selectedDates = [];
                    break;
                default:
                    throw new Error("Invalid selection value");
            }
            this._onChangeCallback(this.selectedDates);
            this._rangeStarted = false;
            this._selection = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "viewDate", {
        get: function () {
            return this._viewDate;
        },
        set: function (value) {
            this._viewDate = new Date(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "value", {
        get: function () {
            return this.selectedDates;
        },
        set: function (val) {
            this.selectDate(val);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "activeView", {
        get: function () {
            return this._activeView;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "monthAction", {
        get: function () {
            return this._monthAction;
        },
        enumerable: true,
        configurable: true
    });
    IgxCalendarComponent.prototype.registerOnChange = function (fn) { this._onChangeCallback = fn; };
    IgxCalendarComponent.prototype.registerOnTouched = function (fn) { this._onTouchedCallback = fn; };
    IgxCalendarComponent.prototype.writeValue = function (value) {
        this.selectedDates = value;
    };
    IgxCalendarComponent.prototype.ngOnInit = function () {
        this.calendarModel.firstWeekDay = this.weekStart;
        var today = new Date(Date.now());
        if (!this._viewDate) {
            this._viewDate = new Date(today);
        }
        this.headerDate = new Date(today);
    };
    IgxCalendarComponent.prototype.generateWeekHeader = function () {
        var dayNames = [];
        var rv = this.calendarModel.monthdatescalendar(this.viewDate.getFullYear(), this.viewDate.getMonth())[0];
        for (var _i = 0, rv_1 = rv; _i < rv_1.length; _i++) {
            var day = rv_1[_i];
            dayNames.push(day.date.toLocaleString(this.locale, { weekday: this.formatOptions.weekday }));
        }
        return dayNames;
    };
    Object.defineProperty(IgxCalendarComponent.prototype, "getCalendarMonth", {
        get: function () {
            return this.calendarModel.monthdatescalendar(this.viewDate.getFullYear(), this.viewDate.getMonth(), true);
        },
        enumerable: true,
        configurable: true
    });
    IgxCalendarComponent.prototype.onDateClick = function (event) {
        var target = event.target;
        if (target.nodeName.toLowerCase() !== "span") {
            return;
        }
        if (target.dataset.prevmonth) {
            this.prevMonth();
        }
        if (target.dataset.nextmonth) {
            this.nextMonth();
        }
        var value = new Date(this._viewDate.getFullYear(), this._viewDate.getMonth(), parseInt(target.textContent, 10));
        this.selectDate(value);
    };
    IgxCalendarComponent.prototype.selectDate = function (date) {
        switch (this.selection) {
            case "single":
                this.selectSingle(date);
                break;
            case "multi":
                this.selectMulti(date);
                break;
            case "range":
                this.selectRange(date);
                break;
            default:
                this.selectSingle(date);
        }
        this.onSelection.emit(this.selectedDates);
    };
    IgxCalendarComponent.prototype.handleKeyDown = function (event) {
        if (event.key.startsWith("Page")) {
            this.handlePageUpDown(event);
            return;
        }
        if (event.key.endsWith("Left") || event.key.endsWith("Right") ||
            event.key.endsWith("Up") || event.key.endsWith("Down")) {
            this.handleKeyboardNavigation(event);
            return;
        }
        switch (event.key) {
            case "Home":
                event.preventDefault();
                this.elementRef.nativeElement.querySelectorAll("[data-curmonth='true']")[0].focus();
                break;
            case "End":
                event.preventDefault();
                var curentDates = this.elementRef.nativeElement.querySelectorAll("[data-curmonth='true']");
                curentDates[curentDates.length - 1].focus();
                break;
            case "Enter":
                this.onDateClick(event);
                break;
            default:
                return;
        }
    };
    IgxCalendarComponent.prototype.selectSingle = function (newVal) {
        this.selectedDates = newVal;
        this._onChangeCallback(this.selectedDates);
    };
    IgxCalendarComponent.prototype.selectMulti = function (newVal) {
        if (newVal instanceof Array) {
            // XXX: Behavior for deselect with array
            this.selectedDates = this.selectedDates.concat(newVal);
        }
        else {
            if (this.selectedDates.every(function (date) { return date.toDateString() !== newVal.toDateString(); })) {
                this.selectedDates.push(newVal);
            }
            else {
                // Deselect if already selected
                this.selectedDates = this.selectedDates.filter(function (date) { return date.toDateString() !== newVal.toDateString(); });
            }
        }
        this._onChangeCallback(this.selectedDates);
    };
    IgxCalendarComponent.prototype.selectRange = function (newVal) {
        if (newVal instanceof Array) {
            this._rangeStarted = false;
            newVal.sort(function (a, b) { return a.valueOf() - b.valueOf(); });
            var start = newVal[0];
            this.selectedDates = [start];
            while (start.toDateString() !== newVal[newVal.length - 1].toDateString()) {
                start = this.calendarModel.timedelta(start, "day", 1);
                this.selectedDates.push(start);
            }
        }
        else {
            // Single date toggle on range selection
            if (!this._rangeStarted) {
                this._rangeStarted = true;
                this.selectedDates = [newVal];
            }
            else {
                // End value for range selection mode; toggle off
                this._rangeStarted = false;
                // Selected range end is the same as start; toggle new range selection
                if (this.selectedDates[0].toDateString() === newVal.toDateString()) {
                    this.selectedDates = [];
                    this._onChangeCallback(this.selectedDates);
                    return;
                }
                this.selectedDates.push(newVal);
                this.selectedDates.sort(function (a, b) { return a.valueOf() - b.valueOf(); });
                var start = this.selectedDates[0];
                var end = this.selectedDates.pop();
                while (start.toDateString() !== end.toDateString()) {
                    start = this.calendarModel.timedelta(start, "day", 1);
                    this.selectedDates.push(start);
                }
            }
        }
        this._onChangeCallback(this.selectedDates);
    };
    IgxCalendarComponent.prototype.prevMonth = function () {
        this._viewDate = this.calendarModel.timedelta(this._viewDate, "month", -1);
        this._monthAction = "prev";
    };
    IgxCalendarComponent.prototype.nextMonth = function () {
        this._viewDate = this.calendarModel.timedelta(this._viewDate, "month", 1);
        this._monthAction = "next";
    };
    // Event handlers for scrolling/keyboard interaction
    // Event handlers for scrolling/keyboard interaction
    IgxCalendarComponent.prototype.handleScroll = 
    // Event handlers for scrolling/keyboard interaction
    function (event) {
        event.preventDefault();
        event.stopPropagation();
        var currentYear = new Date(Date.now()).getFullYear();
        var delta = event.deltaY < 0 ? 1 : -1;
        // Limit to [-100, +100] years
        if (delta > 0 && this._viewDate.getFullYear() - currentYear >= 95) {
            return;
        }
        if (delta < 0 && currentYear - this._viewDate.getFullYear() >= 95) {
            return;
        }
        this._viewDate = this.calendarModel.timedelta(this._viewDate, "year", delta);
    };
    IgxCalendarComponent.prototype.handlePageUpDown = function (event) {
        event.preventDefault();
        if (event.key === "PageUp") {
            if (event.shiftKey) {
                this.viewDate = this.calendarModel.timedelta(this.viewDate, "year", -1);
            }
            else {
                this.prevMonth();
            }
        }
        else {
            if (event.shiftKey) {
                this.viewDate = this.calendarModel.timedelta(this.viewDate, "year", 1);
            }
            else {
                this.nextMonth();
            }
        }
    };
    IgxCalendarComponent.prototype.handleKeyboardNavigation = function (event) {
        event.preventDefault();
        if (event.target.nodeName.toLowerCase() !== "span") {
            return;
        }
        var target = event.target;
        var dest = null;
        if (event.key.endsWith("Left")) {
            dest = target.previousElementSibling;
            if (dest) {
                dest.focus();
            }
        }
        if (event.key.endsWith("Right")) {
            dest = target.nextElementSibling;
            if (dest) {
                dest.focus();
            }
        }
        if (event.key.endsWith("Down")) {
            var targetIndex = Array.from(target.parentNode.children).indexOf(target);
            dest = target.parentNode.nextElementSibling;
            if (dest) {
                dest.children[targetIndex].focus();
            }
        }
        if (event.key.endsWith("Up")) {
            var targetIndex = Array.from(target.parentNode.children).indexOf(target);
            dest = target.parentNode.previousElementSibling;
            if (dest) {
                dest.children[targetIndex].focus();
            }
        }
    };
    // Util methods for the template
    // Util methods for the template
    IgxCalendarComponent.prototype.getMonthName = 
    // Util methods for the template
    function (date) {
        return date.toLocaleString(this.locale, { month: this.formatOptions.month });
    };
    IgxCalendarComponent.prototype.getFormattedDate = function () {
        var date = this.selectedDates ? this.selectedDates : this.headerDate;
        return {
            monthday: date.toLocaleString(this.locale, { month: this.formatOptions.month, day: this.formatOptions.day }),
            weekday: date.toLocaleString(this.locale, { weekday: this.formatOptions.weekday })
        };
    };
    IgxCalendarComponent.prototype.getHeaderYear = function () {
        var res = this.headerDate.toLocaleString(this.locale, { year: this.formatOptions.year });
        if (this.selectedDates) {
            res = this.selectedDates.toLocaleString(this.locale, { year: this.formatOptions.year });
        }
        return res;
    };
    IgxCalendarComponent.prototype.isInactive = function (day) {
        return day.isNextMonth || day.isPrevMonth;
    };
    IgxCalendarComponent.prototype.isWeekend = function (day) {
        return day.date.getDay() === 0 || day.date.getDay() === 6;
    };
    IgxCalendarComponent.prototype.isCurrentMonth = function (value) {
        return this.viewDate.getMonth() === value.getMonth();
    };
    IgxCalendarComponent.prototype.isCurrentYear = function (value) {
        return this.viewDate.getFullYear() === value;
    };
    IgxCalendarComponent.prototype.isSelected = function (day) {
        if (this.selection === "multi" || this.selection === "range") {
            for (var _i = 0, _a = this.selectedDates; _i < _a.length; _i++) {
                var date = _a[_i];
                if (date.toDateString() === day.date.toDateString()) {
                    return true;
                }
            }
            return false;
        }
        if (this.selectedDates) {
            return day.date.toDateString() === this.selectedDates.toDateString();
        }
        return false;
    };
    IgxCalendarComponent.prototype.isToday = function (day) {
        var today = new Date(Date.now());
        return (day.date.getFullYear() === today.getFullYear() &&
            day.date.getMonth() === today.getMonth() &&
            day.date.getDate() === today.getDate());
    };
    Object.defineProperty(IgxCalendarComponent.prototype, "isDefaultView", {
        get: function () {
            return this.activeView === CalendarView.DEFAULT;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "isYearView", {
        get: function () {
            return this.activeView === CalendarView.YEAR;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCalendarComponent.prototype, "isDecadeView", {
        get: function () {
            return this.activeView === CalendarView.DECADE;
        },
        enumerable: true,
        configurable: true
    });
    IgxCalendarComponent.prototype.activeViewYear = function () {
        this._activeView = CalendarView.YEAR;
    };
    IgxCalendarComponent.prototype.activeViewDecade = function () {
        this._activeView = CalendarView.DECADE;
    };
    // XXX: WiP! Will still have to discuss what are we showing
    //      and how are we showing it
    // XXX: WiP! Will still have to discuss what are we showing
    //      and how are we showing it
    IgxCalendarComponent.prototype.getDecade = 
    // XXX: WiP! Will still have to discuss what are we showing
    //      and how are we showing it
    function () {
        var res = [];
        var start = this._viewDate.getFullYear() - 5;
        var end = this._viewDate.getFullYear() + 6;
        for (var _i = 0, _a = range(start, end); _i < _a.length; _i++) {
            var year = _a[_i];
            res.push(year);
        }
        return res;
    };
    IgxCalendarComponent.prototype.getYear = function () {
        var start = new Date(this._viewDate.getFullYear(), 0, 1);
        var res = [];
        for (var i = 0; i < 12; i++) {
            res.push(start);
            start = this.calendarModel.timedelta(start, "month", 1);
        }
        return res;
    };
    IgxCalendarComponent.prototype.changeYear = function (event) {
        var year = parseInt(event.target.textContent, 10);
        this._viewDate = new Date(year, this._viewDate.getMonth(), 1);
        this._activeView = CalendarView.DEFAULT;
    };
    IgxCalendarComponent.prototype.changeMonth = function (event) {
        var month = event.target.dataset.index;
        this._viewDate = new Date(this._viewDate.getFullYear(), month, 1);
        this._activeView = CalendarView.DEFAULT;
    };
    IgxCalendarComponent.prototype.dateTracker = function (index, item) {
        return item.date.getMonth() + "--" + item.date.getDate();
    };
    IgxCalendarComponent.prototype.rowTracker = function (index, item) {
        return "" + item[index].date.getMonth() + item[index].date.getDate();
    };
    IgxCalendarComponent.prototype.monthTracker = function (index, item) {
        return index;
    };
    IgxCalendarComponent.decorators = [
        { type: Component, args: [{
                    animations: [
                        trigger("animateView", [
                            transition("void => 0", useAnimation(fadeIn)),
                            transition("void => *", useAnimation(scaleInCenter, {
                                params: {
                                    duration: ".2s",
                                    fromScale: .9
                                }
                            }))
                        ]),
                        trigger("animateChange", [
                            transition("* => prev", useAnimation(slideInLeft, {
                                params: {
                                    fromPosition: "translateX(-30%)"
                                }
                            })),
                            transition("* => next", useAnimation(slideInRight, {
                                params: {
                                    fromPosition: "translateX(30%)"
                                }
                            }))
                        ])
                    ],
                    providers: [{ provide: NG_VALUE_ACCESSOR, useExisting: IgxCalendarComponent, multi: true }],
                    selector: "igx-calendar",
                    styles: [".igx-calendar,.igx-calendar--vertical{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap;width:100%;overflow:hidden;outline:none}.igx-calendar--vertical{-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row nowrap;flex-flow:row nowrap}.igx-calendar--vertical .igx-calendar__header{width:168px}.igx-calendar__header{background-color:#e41c77;color:#fff;padding:1.5em 1em}.igx-calendar__header-year{margin:0;color:rgba(255,255,255,0.8);font-size:1.125em}.igx-calendar__header-date,.igx-calendar--vertical .igx-calendar__header-date{display:-webkit-box;display:-ms-flexbox;display:flex;margin:0;font-size:2.375em;line-height:1em}.igx-calendar--vertical .igx-calendar__header-date{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap}.igx-calendar__body-picker .date__el:hover,.igx-calendar__body-picker .date__el:focus{color:#e41c77;cursor:pointer}.igx-calendar__body-picker{display:-webkit-box;display:-ms-flexbox;display:flex;height:56px;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center;padding-bottom:1.5em;padding-left:1.5em;padding-right:1.5em}.igx-calendar__body-picker .next,.igx-calendar__body-picker .prev{color:rgba(0,0,0,0.74);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;cursor:pointer}.igx-calendar__body-picker .next:hover,.igx-calendar__body-picker .prev:hover{color:#e41c77}.igx-calendar__body-picker .date{font-size:1.125em;line-height:1.375em;font-weight:600;text-align:center}.igx-calendar__body{padding-top:1.5em;padding-bottom:1.5em;overflow:hidden}.igx-calendar__body-row,.igx-calendar__body-row--wrap{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;padding:0 1em}.igx-calendar__body-row--wrap{-ms-flex-wrap:wrap;flex-wrap:wrap}.igx-calendar__body-column{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.igx-calendar__label,.igx-calendar__date,.igx-calendar__date--inactive,.igx-calendar__date--selected,.igx-calendar__date--current,.igx-calendar__date--weekend,.igx-calendar__year,.igx-calendar__year--current,.igx-calendar__month,.igx-calendar__month--current{display:-webkit-box;display:-ms-flexbox;display:flex;margin:.125em;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:2.5em;height:2.5em;font-size:1em;line-height:1.375em;border-radius:1.25em;color:rgba(0,0,0,0.87);cursor:pointer;outline:none;-webkit-transition:background .15s ease-out;-o-transition:background .15s ease-out;transition:background .15s ease-out}.igx-calendar__label{color:rgba(0,0,0,0.26);cursor:default}.igx-calendar__date--weekend{color:rgba(0,0,0,0.26)}.igx-calendar__year,.igx-calendar__year--current{font-size:1.125em}.igx-calendar__year--current{font-size:1.5em;color:#e41c77}.igx-calendar__year:hover,.igx-calendar__year:focus{color:#e41c77}.igx-calendar__month:hover,.igx-calendar__month:focus{color:#e41c77}.igx-calendar__month,.igx-calendar__month--current{display:-webkit-box;display:-ms-flexbox;display:flex;margin:0 .75em;-webkit-box-flex:1;-ms-flex:1 0 25%;flex:1 0 25%;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:91px}.igx-calendar__month--current{color:#e41c77}.igx-calendar__date--inactive{color:rgba(0,0,0,0.26)}.igx-calendar__date--selected{position:relative;color:#fff;background-color:#e41c77 !important;font-weight:600}.igx-calendar__date--current{color:#e41c77;font-weight:600}.igx-calendar__date:hover,.igx-calendar__date:focus,.igx-calendar__date--inactive:hover,.igx-calendar__date--inactive:focus,.igx-calendar__date--current:hover,.igx-calendar__date--current:focus,.igx-calendar__date--weekend:hover,.igx-calendar__date--weekend:focus{background-color:rgba(0,0,0,0.04)}.igx-calendar__date--inactive{cursor:pointer}:host{-webkit-box-flex:1;-ms-flex:1 0 100%;flex:1 0 100%}"],
                    template: "<div tabindex=\"0\" (keydown)=\"handleKeyDown($event)\" class=\"igx-calendar\" role=\"grid\" aria-labelledby=\"calendar\">      <div class=\"igx-calendar__header\" *ngIf=\"selection === 'single'\">         <h5 class=\"igx-calendar__header-year\">{{ getHeaderYear() }}</h5>         <h2 class=\"igx-calendar__header-date\">             <span>                 {{ getFormattedDate().weekday }},&nbsp;             </span>             <span>                 {{ getFormattedDate().monthday }}             </span>         </h2>     </div>       <div *ngIf=\"isDefaultView\" class=\"igx-calendar__body\" [@animateView]=\"activeView\" (swiperight)=\"prevMonth()\" (swipeleft)=\"nextMonth()\">         <div class=\"igx-calendar__body-picker\">             <div class=\"prev\" (click)=\"prevMonth()\">                 <igx-icon fontSet=\"material\" name=\"keyboard_arrow_left\"></igx-icon>             </div>             <div class=\"date\">                 <span (click)=\"activeViewYear()\" class=\"date__el\">{{ getMonthName(viewDate) }}</span>                 <span (click)=\"activeViewDecade()\" class=\"date__el\">{{ viewDate.getFullYear() }}</span>             </div>             <div class=\"next\" (click)=\"nextMonth()\">                 <igx-icon fontSet=\"material\" name=\"keyboard_arrow_right\"></igx-icon>             </div>         </div>          <div class=\"igx-calendar__body-row\">             <span *ngFor=\"let dayName of generateWeekHeader()\" class=\"igx-calendar__label\">                 {{ dayName }}             </span>         </div>         <div *ngFor=\"let week of getCalendarMonth; trackBy: rowTracker\" class=\"igx-calendar__body-row\" (click)=\"onDateClick($event)\"             [@animateChange]=\"monthAction\">             <span tabindex=\"0\" *ngFor=\"let day of week; trackBy: dateTracker\" [attr.data-prevmonth]=\"day.isPrevMonth ? true : null\" [attr.data-nextmonth]=\"day.isNextMonth ? true : null\"                 [attr.data-curmonth]=\"day.isCurrentMonth ? true : null\" [class.igx-calendar__date--inactive]=\"isInactive(day)\"                 [class.igx-calendar__date]=\"day.isCurrentMonth && !isWeekend(day) && !isSelected(day)\" [class.igx-calendar__date--weekend]=\"isWeekend(day)\"                 [class.igx-calendar__date--current]=\"isToday(day) && !isSelected(day)\" [class.igx-calendar__date--selected]=\"isSelected(day)\">                 {{ day.date.getDate() }}             </span>         </div>      </div>      <div *ngIf=\"isYearView\" class=\"igx-calendar__body\" [@animateView]=\"activeView\">         <div class=\"igx-calendar__body-row--wrap\" (click)=\"changeMonth($event)\">             <div [attr.data-index]=\"i\" *ngFor=\"let month of getYear(); trackBy: monthTracker; let i = index;\" [class.igx-calendar__month]=\"!isCurrentMonth(month)\"                 [class.igx-calendar__month--current]=\"isCurrentMonth(month)\">                 {{ getMonthName(month) }}             </div>         </div>     </div>      <div *ngIf=\"isDecadeView\" class=\"igx-calendar__body\" [@animateView]=\"activeView\">         <div class=\"igx-calendar__body-column\" (click)=\"changeYear($event)\" (wheel)=\"handleScroll($event)\">             <span *ngFor=\"let year of getDecade()\" [class.igx-calendar__year]=\"!isCurrentYear(year)\" [class.igx-calendar__year--current]=\"isCurrentYear(year)\">                 {{ year }}             </span>         </div>     </div> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxCalendarComponent.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    IgxCalendarComponent.propDecorators = {
        "weekStart": [{ type: Input },],
        "locale": [{ type: Input },],
        "selection": [{ type: Input },],
        "viewDate": [{ type: Input },],
        "onSelection": [{ type: Output },],
        "value": [{ type: Input },],
        "formatOptions": [{ type: Input },],
    };
    return IgxCalendarComponent;
}());
export { IgxCalendarComponent };
var IgxCalendarModule = /** @class */ (function () {
    function IgxCalendarModule() {
    }
    IgxCalendarModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxCalendarComponent],
                    exports: [IgxCalendarComponent],
                    imports: [CommonModule, FormsModule, BrowserAnimationsModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxCalendarModule.ctorParameters = function () { return []; };
    return IgxCalendarModule;
}());
export { IgxCalendarModule };
//# sourceMappingURL=calendar.component.js.map