import { CommonModule } from "@angular/common";
import { Component, EventEmitter, HostBinding, Input, NgModule, Output, ViewEncapsulation } from "@angular/core";
import { IgxIconModule } from "../icon/icon.component";
export var Direction;
(function (Direction) {
    Direction[Direction["NONE"] = 0] = "NONE";
    Direction[Direction["NEXT"] = 1] = "NEXT";
    Direction[Direction["PREV"] = 2] = "PREV";
})(Direction || (Direction = {}));
/**
 * A carousel component is used to browse or navigate through a collection of slides - galleries of images,
 * cards, on-boarding tutorials or page-based interfaces. It can be used as a separate fulls creen element
 * or inside another component
 *
 * ```
 * <igx-carousel (event output bindings) [input bindings] >
 *     ....
 * </igx-carousel>
 * ```
 * @export
 * @class IgxCarousel
 * @implements {OnDestroy}
 */
var IgxCarousel = /** @class */ (function () {
    function IgxCarousel() {
        /**
             * Sets whether the carousel should loop back to the first slide
             * after reaching the last slide.
             *
             * Default value is true
             *
             * @type {boolean}
             * @memberOf IgxCarousel
             */
        this.loop = true;
        /**
             * Sets whether the carousel can pause the slide transitions.
             *
             * Default value is true
             *
             * @type {boolean}
             * @memberOf IgxCarousel
             */
        this.pause = true;
        /**
             * Controls whether the carousel should render the left/right navigation buttons.
             *
             * Default value is true
             *
             * @type {boolean}
             * @memberOf IgxCarousel
             */
        this.navigation = true;
        /**
             * An event that is emitted after a slide transition has happened.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarousel
             */
        this.onSlideChanged = new EventEmitter();
        /**
             * An event that is emitted after a slide has been added to the carousel.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarousel
             */
        this.onSlideAdded = new EventEmitter();
        /**
             * An event that is emitted after a slide has been removed from the carousel.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarousel
             */
        this.onSlideRemoved = new EventEmitter();
        /**
             * An event that is emitted after the carousel has been paused.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarousel
             */
        this.onCarouselPaused = new EventEmitter();
        /**
             * An event that is emitted after the carousel has resumed transitioning between slides.
             * Provides a reference to the IgxCarousel as an event argument.
             *
             * @type {EventEmitter}
             * @memberOf IgxCarousel
             */
        this.onCarouselPlaying = new EventEmitter();
        /**
             * The collection of slides currently in the carousel
             *
             * @type {Array<Slide>}
             * @memberOf IgxCarousel
             */
        this.slides = [];
        this._total = 0;
    }
    Object.defineProperty(IgxCarousel.prototype, "interval", {
        get: function () {
            return this._interval;
        },
        set: function (value) {
            this._interval = +value;
            this._restartInterval();
        },
        enumerable: true,
        configurable: true
    });
    IgxCarousel.prototype.ngOnDestroy = function () {
        this._destroyed = true;
        if (this._lastInterval) {
            clearInterval(this._lastInterval);
        }
    };
    IgxCarousel.prototype.setAriaLabel = function (slide) {
        return "Item " + (slide.index + 1) + " of " + this.total;
    };
    Object.defineProperty(IgxCarousel.prototype, "total", {
        /**
         * The total number of slides in the carousel.
         *
         * @readonly
         * @type {number}
         * @memberOf IgxCarousel
         */
        get: /**
             * The total number of slides in the carousel.
             *
             * @readonly
             * @type {number}
             * @memberOf IgxCarousel
             */
        function () {
            return this._total;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCarousel.prototype, "current", {
        /**
         * The index of the slide being currently shown.
         *
         * @readonly
         * @type {number}
         * @memberOf IgxCarousel
         */
        get: /**
             * The index of the slide being currently shown.
             *
             * @readonly
             * @type {number}
             * @memberOf IgxCarousel
             */
        function () {
            return !this._currentSlide ? 0 : this._currentSlide.index;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCarousel.prototype, "isPlaying", {
        /**
         * Returns the state of the carousel - paused or playing.
         *
         * @readonly
         * @type {boolean}
         * @memberOf IgxCarousel
         */
        get: /**
             * Returns the state of the carousel - paused or playing.
             *
             * @readonly
             * @type {boolean}
             * @memberOf IgxCarousel
             */
        function () {
            return this._playing;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxCarousel.prototype, "isDestroyed", {
        /**
         * Whether the carousel is destroyed, i.e. `ngOnDestroy` has been called.
         *
         * @readonly
         * @type {boolean}
         * @memberOf Carousel
         */
        get: /**
             * Whether the carousel is destroyed, i.e. `ngOnDestroy` has been called.
             *
             * @readonly
             * @type {boolean}
             * @memberOf Carousel
             */
        function () {
            return this._destroyed;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Returns the slide corresponding to the provided index or null.
     *
     * @param {number} index
     * @returns {IgxSlide}
     *
     * @memberOf IgxCarousel
     */
    /**
         * Returns the slide corresponding to the provided index or null.
         *
         * @param {number} index
         * @returns {IgxSlide}
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.get = /**
         * Returns the slide corresponding to the provided index or null.
         *
         * @param {number} index
         * @returns {IgxSlide}
         *
         * @memberOf IgxCarousel
         */
    function (index) {
        for (var _i = 0, _a = this.slides; _i < _a.length; _i++) {
            var each = _a[_i];
            if (each.index === index) {
                return each;
            }
        }
    };
    /**
     * Adds a new slide to the carousel.
     *
     * @param {IgxSlide} slide
     *
     * @memberOf IgxCarousel
     */
    /**
         * Adds a new slide to the carousel.
         *
         * @param {IgxSlide} slide
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.add = /**
         * Adds a new slide to the carousel.
         *
         * @param {IgxSlide} slide
         *
         * @memberOf IgxCarousel
         */
    function (slide) {
        slide.index = this.total;
        this.slides.push(slide);
        this._total += 1;
        if (this.total === 1 || slide.active) {
            this.select(slide);
            if (this.total === 1) {
                this.play();
            }
        }
        else {
            slide.active = false;
        }
        this.onSlideAdded.emit(this);
    };
    /**
     * Removes the given slide from the carousel.
     *
     * @param {IgxSlide} slide
     * @returns
     *
     * @memberOf IgxCarousel
     */
    /**
         * Removes the given slide from the carousel.
         *
         * @param {IgxSlide} slide
         * @returns
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.remove = /**
         * Removes the given slide from the carousel.
         *
         * @param {IgxSlide} slide
         * @returns
         *
         * @memberOf IgxCarousel
         */
    function (slide) {
        this.slides.splice(slide.index, 1);
        this._total -= 1;
        if (!this.total) {
            this._currentSlide = null;
            return;
        }
        for (var i = 0; i < this.total; i++) {
            this.slides[i].index = i;
        }
        this.onSlideRemoved.emit(this);
    };
    /**
     * Kicks in a transition for a given slide with a given direction.
     *
     * @param {IgxSlide} slide
     * @param {Direction} [direction=Direction.NONE]
     *
     * @memberOf IgxCarousel
     */
    /**
         * Kicks in a transition for a given slide with a given direction.
         *
         * @param {IgxSlide} slide
         * @param {Direction} [direction=Direction.NONE]
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.select = /**
         * Kicks in a transition for a given slide with a given direction.
         *
         * @param {IgxSlide} slide
         * @param {Direction} [direction=Direction.NONE]
         *
         * @memberOf IgxCarousel
         */
    function (slide, direction) {
        if (direction === void 0) { direction = Direction.NONE; }
        var newIndex = slide.index;
        if (direction === Direction.NONE) {
            direction = newIndex > this.current ? Direction.NEXT : Direction.PREV;
        }
        if (slide && slide !== this._currentSlide) {
            this._moveTo(slide, direction);
        }
    };
    /**
     * Transitions to the next slide in the carousel.
     *
     * @returns
     *
     * @memberOf IgxCarousel
     */
    /**
         * Transitions to the next slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.next = /**
         * Transitions to the next slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarousel
         */
    function () {
        var index = (this.current + 1) % this.total;
        if (index === 0 && !this.loop) {
            this.stop();
            return;
        }
        return this.select(this.get(index), Direction.NEXT);
    };
    /**
     * Transitions to the previous slide in the carousel.
     *
     * @returns
     *
     * @memberOf IgxCarousel
     */
    /**
         * Transitions to the previous slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.prev = /**
         * Transitions to the previous slide in the carousel.
         *
         * @returns
         *
         * @memberOf IgxCarousel
         */
    function () {
        var index = this.current - 1 < 0 ?
            this.total - 1 : this.current - 1;
        if (!this.loop && index === this.total - 1) {
            this.stop();
            return;
        }
        return this.select(this.get(index), Direction.PREV);
    };
    /**
     * Resumes playing of the carousel if in paused state.
     * No-op otherwise.
     *
     *
     * @memberOf IgxCarousel
     */
    /**
         * Resumes playing of the carousel if in paused state.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.play = /**
         * Resumes playing of the carousel if in paused state.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarousel
         */
    function () {
        if (!this._playing) {
            this._playing = true;
            this.onCarouselPlaying.emit(this);
            this._restartInterval();
        }
    };
    /**
     * Stops slide transitions if the `pause` options is set to `true`.
     * No-op otherwise.
     *
     *
     * @memberOf IgxCarousel
     */
    /**
         * Stops slide transitions if the `pause` options is set to `true`.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarousel
         */
    IgxCarousel.prototype.stop = /**
         * Stops slide transitions if the `pause` options is set to `true`.
         * No-op otherwise.
         *
         *
         * @memberOf IgxCarousel
         */
    function () {
        if (this.pause) {
            this._playing = false;
            this.onCarouselPaused.emit(this);
            this._resetInterval();
        }
    };
    IgxCarousel.prototype.onKeydown = function (event) {
        switch (event.key) {
            case "ArrowLeft":
                this.prev();
                break;
            case "ArrowRight":
                this.next();
                break;
            default:
                return;
        }
    };
    IgxCarousel.prototype._moveTo = function (slide, direction) {
        if (this._destroyed) {
            return;
        }
        slide.direction = direction;
        slide.active = true;
        if (this._currentSlide) {
            this._currentSlide.direction = direction;
            this._currentSlide.active = false;
        }
        this._currentSlide = slide;
        this.onSlideChanged.emit(this);
        this._restartInterval();
    };
    IgxCarousel.prototype._resetInterval = function () {
        if (this._lastInterval) {
            clearInterval(this._lastInterval);
            this._lastInterval = null;
        }
    };
    IgxCarousel.prototype._restartInterval = function () {
        var _this = this;
        this._resetInterval();
        if (!isNaN(this.interval) && this.interval > 0) {
            this._lastInterval = setInterval(function () {
                var tick = +_this.interval;
                if (_this._playing && _this.total && !isNaN(tick) && tick > 0) {
                    _this.next();
                }
                else {
                    _this.stop();
                }
            }, this.interval);
        }
    };
    IgxCarousel.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    host: {
                        role: "region"
                    },
                    selector: "igx-carousel",
                    styles: [".igx-carousel{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap;-webkit-transform-style:preserve-3d;transform-style:preserve-3d;outline:none}.igx-carousel__inner{position:relative;width:100%;height:inherit;overflow:hidden}.igx-carousel__inner .active{display:block}.igx-carousel__arrow,.igx-carousel__arrow--prev,.igx-carousel__arrow--next{display:-webkit-box;display:-ms-flexbox;display:flex;margin:0 1em;position:absolute;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;width:46px;height:46px;top:50%;-webkit-transform:translateY(-50%);-ms-transform:translateY(-50%);transform:translateY(-50%);color:#fff;cursor:pointer;background-color:rgba(255,255,255,0.3);border-radius:50%;-webkit-box-shadow:0 1px 3px 0 rgba(0,0,0,0.26),0 1px 1px 0 rgba(0,0,0,0.12),0 2px 1px -1px rgba(0,0,0,0.08);box-shadow:0 1px 3px 0 rgba(0,0,0,0.26),0 1px 1px 0 rgba(0,0,0,0.12),0 2px 1px -1px rgba(0,0,0,0.08);-webkit-transition:opacity .25s ease-out;-o-transition:opacity .25s ease-out;transition:opacity .25s ease-out}.igx-carousel__arrow span,.igx-carousel__arrow--prev span,.igx-carousel__arrow--next span{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.igx-carousel__arrow--prev:hover,.igx-carousel__arrow--next:hover{opacity:.7}.igx-carousel__arrow--next{right:0}.igx-carousel__arrow--prev{left:0}.igx-carousel__indicators{display:-webkit-box;display:-ms-flexbox;display:flex;margin:1em 0;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;position:absolute;list-style:none;z-index:10;bottom:0;left:50%;-webkit-transform:translateX(-50%);-ms-transform:translateX(-50%);transform:translateX(-50%);padding:0;opacity:.85}.igx-carousel__indicators li{margin:0 .3125em;position:relative;width:12px;height:12px;text-indent:-9999px;cursor:pointer;border:1px solid #fff;border-radius:50%;background-color:rgba(255,255,255,0.2);-webkit-transition:-webkit-transform 0.25s cubic-bezier(0.55, 0.085, 0.68, 0.53);transition:-webkit-transform 0.25s cubic-bezier(0.55, 0.085, 0.68, 0.53);-o-transition:transform 0.25s cubic-bezier(0.55, 0.085, 0.68, 0.53);transition:transform 0.25s cubic-bezier(0.55, 0.085, 0.68, 0.53);transition:transform 0.25s cubic-bezier(0.55, 0.085, 0.68, 0.53), -webkit-transform 0.25s cubic-bezier(0.55, 0.085, 0.68, 0.53);-webkit-box-shadow:0 1px 3px 0 rgba(0,0,0,0.26),0 1px 1px 0 rgba(0,0,0,0.12),0 2px 1px -1px rgba(0,0,0,0.08);box-shadow:0 1px 3px 0 rgba(0,0,0,0.26),0 1px 1px 0 rgba(0,0,0,0.12),0 2px 1px -1px rgba(0,0,0,0.08)}.igx-carousel__indicators li::after{content:'';position:absolute;top:-1px;bottom:0;left:-1px;right:0;width:inherit;height:inherit;border-radius:inherit;background:#fff;-webkit-transform:scale(0);-ms-transform:scale(0);transform:scale(0)}.igx-carousel__indicators li:hover{-webkit-transform:scale(1.2);-ms-transform:scale(1.2);transform:scale(1.2)}.igx-carousel__indicators .active::after{-webkit-animation:scale-in 0.3s cubic-bezier(0.25, 0.46, 0.45, 0.94) forwards;animation:scale-in 0.3s cubic-bezier(0.25, 0.46, 0.45, 0.94) forwards}.igx-slide{display:none;width:100%;height:100%;position:relative;-webkit-transition:.5s ease-in-out left;-o-transition:.5s ease-in-out left;transition:.5s ease-in-out left;-webkit-backface-visibility:hidden;backface-visibility:hidden;-webkit-perspective:1000px;perspective:1000px}.igx-slide img{width:inherit;height:inherit;-webkit-transform:scale(1.01);-ms-transform:scale(1.01);transform:scale(1.01)}@-webkit-keyframes goUp{from{-webkit-transform:translateY(100%);transform:translateY(100%)}}@keyframes goUp{from{-webkit-transform:translateY(100%);transform:translateY(100%)}}@-webkit-keyframes goDown{from{-webkit-transform:translateY(-100%);transform:translateY(-100%)}}@keyframes goDown{from{-webkit-transform:translateY(-100%);transform:translateY(-100%)}}@-webkit-keyframes goLeft{from{-webkit-transform:translateX(-100%);transform:translateX(-100%)}}@keyframes goLeft{from{-webkit-transform:translateX(-100%);transform:translateX(-100%)}}@-webkit-keyframes goRight{from{-webkit-transform:translateX(100%);transform:translateX(100%)}}@keyframes goRight{from{-webkit-transform:translateX(100%);transform:translateX(100%)}}@-webkit-keyframes scale-in{80%{-webkit-transform:scale(1.2);transform:scale(1.2)}100%{-webkit-transform:scale(1);transform:scale(1)}}@keyframes scale-in{80%{-webkit-transform:scale(1.2);transform:scale(1.2)}100%{-webkit-transform:scale(1);transform:scale(1)}}@-webkit-keyframes fade{0%{opacity:.25}50%{opacity:1}100%{opacity:0}}@keyframes fade{0%{opacity:.25}50%{opacity:1}100%{opacity:0}}"],
                    template: "<div tabindex=\"0\" aria-label=\"carousel\" class=\"igx-carousel\"         (mouseenter)=\"stop()\"         (mouseleave)=\"play()\"         (swipeleft)=\"next()\"         (swiperight)=\"prev()\"         (keydown)=\"onKeydown($event)\"         (tap)=\"isPlaying ? stop() : play()\">     <ul class=\"igx-carousel__indicators\" [hidden]=\"slides.length <= 1\">         <li *ngFor=\"let slide of slides\" [attr.aria-label]=\"setAriaLabel(slide)\" [attr.aria-selected]=\"slide.active\" [class.active]=\"slide.active === true\"             (click)=\"select(slide)\"></li>     </ul>     <div class=\"igx-carousel__inner\" role=\"list\">         <ng-content></ng-content>     </div>     <div ng-template=\"ngIf navigation\">         <a role=\"button\" tabindex=\"0\" class=\"igx-carousel__arrow--prev\" (click)=\"prev()\" [hidden]=\"!slides.length\">             <igx-icon fontSet=\"material\" name=\"arrow_back\"></igx-icon>         </a>         <a role=\"button\" tabindex=\"0\" class=\"igx-carousel__arrow--next\" (click)=\"next()\" [hidden]=\"!slides.length\">             <igx-icon fontSet=\"material\" name=\"arrow_forward\"></igx-icon>         </a>     </div> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxCarousel.ctorParameters = function () { return []; };
    IgxCarousel.propDecorators = {
        "loop": [{ type: Input },],
        "pause": [{ type: Input },],
        "interval": [{ type: Input },],
        "navigation": [{ type: Input },],
        "onSlideChanged": [{ type: Output },],
        "onSlideAdded": [{ type: Output },],
        "onSlideRemoved": [{ type: Output },],
        "onCarouselPaused": [{ type: Output },],
        "onCarouselPlaying": [{ type: Output },],
    };
    return IgxCarousel;
}());
export { IgxCarousel };
/**
 * A slide component that usually holds an image and/or a caption text.
 * IgxSlide is usually a child component of an IgxCarousel.
 *
 * ```
 * <igx-slide [input bindings] >
 *    <ng-content></ng-content>
 * </igx-slide>
 * ```
 *
 * @export
 * @class IgxSlide
 * @implements {OnInit}
 * @implements {OnDestroy}
 */
var IgxSlide = /** @class */ (function () {
    function IgxSlide(carousel) {
        this.carousel = carousel;
    }
    IgxSlide.prototype.ngOnInit = function () {
        this.carousel.add(this);
    };
    IgxSlide.prototype.ngOnDestroy = function () {
        this.carousel.remove(this);
    };
    IgxSlide.decorators = [
        { type: Component, args: [{
                    selector: "igx-slide",
                    template: "<div     role=\"listitem\"     [class.active]=\"active\"     class=\"igx-slide\"     [attr.aria-selected]=\"active\"     [attr.aria-live]=\"active ? 'polite' : null\"     [attr.tabIndex]=\"active ? 0 : null\" >     <ng-content></ng-content> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxSlide.ctorParameters = function () { return [
        { type: IgxCarousel, },
    ]; };
    IgxSlide.propDecorators = {
        "index": [{ type: Input },],
        "direction": [{ type: Input },],
        "active": [{ type: HostBinding, args: ["class.active",] }, { type: Input },],
    };
    return IgxSlide;
}());
export { IgxSlide };
var IgxCarouselModule = /** @class */ (function () {
    function IgxCarouselModule() {
    }
    IgxCarouselModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxCarousel, IgxSlide],
                    exports: [IgxCarousel, IgxSlide],
                    imports: [CommonModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxCarouselModule.ctorParameters = function () { return []; };
    return IgxCarouselModule;
}());
export { IgxCarouselModule };
//# sourceMappingURL=carousel.component.js.map