import { Directive, HostListener, Input, NgModule } from "@angular/core";
import { NavigationService } from "./nav-service";
/**
 * Directive that can toggle targets through provided NavigationService.
 *
 * Usage:
 * ```
 * <button igxNavToggle="ID"> Toggle </button>
 * ```
 * Where the `ID` matches the ID of compatible `IToggleView` component.
 */
var NavigationToggle = /** @class */ (function () {
    function NavigationToggle(nav) {
        this.state = nav;
    }
    NavigationToggle.prototype.toggleNavigationDrawer = function () {
        this.state.toggle(this.target, true);
    };
    NavigationToggle.decorators = [
        { type: Directive, args: [{ selector: "[igxNavToggle]" },] },
    ];
    /** @nocollapse */
    NavigationToggle.ctorParameters = function () { return [
        { type: NavigationService, },
    ]; };
    NavigationToggle.propDecorators = {
        "target": [{ type: Input, args: ["igxNavToggle",] },],
        "toggleNavigationDrawer": [{ type: HostListener, args: ["click",] },],
    };
    return NavigationToggle;
}());
export { NavigationToggle };
/**
 * Directive that can close targets through provided NavigationService.
 *
 * Usage:
 * ```
 * <button igxNavClose="ID"> Close </button>
 * ```
 * Where the `ID` matches the ID of compatible `IToggleView` component.
 */
var NavigationClose = /** @class */ (function () {
    function NavigationClose(nav) {
        this.state = nav;
    }
    NavigationClose.prototype.closeNavigationDrawer = function () {
        this.state.close(this.target, true);
    };
    NavigationClose.decorators = [
        { type: Directive, args: [{ selector: "[igxNavClose]" },] },
    ];
    /** @nocollapse */
    NavigationClose.ctorParameters = function () { return [
        { type: NavigationService, },
    ]; };
    NavigationClose.propDecorators = {
        "target": [{ type: Input, args: ["igxNavClose",] },],
        "closeNavigationDrawer": [{ type: HostListener, args: ["click",] },],
    };
    return NavigationClose;
}());
export { NavigationClose };
var IgxNavigationDirectives = /** @class */ (function () {
    function IgxNavigationDirectives() {
    }
    IgxNavigationDirectives.decorators = [
        { type: NgModule, args: [{
                    declarations: [NavigationClose, NavigationToggle],
                    exports: [NavigationClose, NavigationToggle],
                    providers: [NavigationService]
                },] },
    ];
    /** @nocollapse */
    IgxNavigationDirectives.ctorParameters = function () { return []; };
    return IgxNavigationDirectives;
}());
export { IgxNavigationDirectives };
//# sourceMappingURL=directives.js.map