import { Directive, ElementRef, HostListener, Input, NgModule, NgZone, Renderer2 } from "@angular/core";
var IgxRippleDirective = /** @class */ (function () {
    function IgxRippleDirective(el, renderer, zone) {
        this.el = el;
        this.renderer = renderer;
        this.zone = zone;
        this.rippleTarget = "";
        this.rippleDuration = 600;
        this._centered = false;
        this.animationQueue = [];
        this.container = el.nativeElement;
    }
    Object.defineProperty(IgxRippleDirective.prototype, "centered", {
        set: function (value) {
            this._centered = value || this.centered;
        },
        enumerable: true,
        configurable: true
    });
    IgxRippleDirective.prototype.onMouseDown = function (event) {
        var _this = this;
        this.zone.runOutsideAngular(function () { return _this._ripple(event); });
    };
    IgxRippleDirective.prototype._ripple = function (event) {
        var _this = this;
        var target;
        var top;
        var left;
        var radius;
        var rippleEl;
        var rectBounds;
        // document.body.scrollX always returns 0 in Firefox. Use documentElement instead.
        var scrollLeft = (document.body.scrollLeft || document.documentElement.scrollLeft);
        var scrollTop = (document.body.scrollTop || document.documentElement.scrollTop);
        event.stopPropagation();
        target = (this.rippleTarget ?
            this.container.querySelector(this.rippleTarget) || this.container
            : this.container);
        rectBounds = target.getBoundingClientRect();
        this.renderer.addClass(target, "ig-ripple-host");
        rippleEl = this.renderer.createElement("span");
        this.renderer.appendChild(target, rippleEl);
        this.renderer.addClass(rippleEl, "ig-ripple-host__ripple");
        radius = Math.max(rectBounds.width, rectBounds.height);
        left = event.pageX - rectBounds.left - radius / 2 - scrollLeft;
        top = event.pageY - rectBounds.top - radius / 2 - scrollTop;
        this.renderer.setStyle(rippleEl, "width", radius + "px");
        this.renderer.setStyle(rippleEl, "height", radius + "px");
        this.renderer.setStyle(rippleEl, "top", top + "px");
        this.renderer.setStyle(rippleEl, "left", left + "px");
        if (this._centered) {
            this.renderer.setStyle(rippleEl, "top", "0");
            this.renderer.setStyle(rippleEl, "left", "0");
        }
        if (this.rippleColor) {
            this.renderer.setStyle(rippleEl, "background", this.rippleColor);
        }
        var FRAMES = [
            { opacity: 0.5, transform: "scale(0)" },
            { opacity: 0, transform: "scale(2)" }
        ];
        var animation = rippleEl.animate(FRAMES, {
            duration: this.rippleDuration,
            fill: "forwards"
        });
        this.animationQueue.push(animation);
        animation.onfinish = function () {
            _this.animationQueue.splice(_this.animationQueue.indexOf(animation), 1);
            target.removeChild(rippleEl);
            if (_this.animationQueue.length < 1) {
                _this.renderer.removeClass(target, "ig-ripple-host");
            }
        };
    };
    IgxRippleDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxRipple]"
                },] },
    ];
    /** @nocollapse */
    IgxRippleDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
        { type: NgZone, },
    ]; };
    IgxRippleDirective.propDecorators = {
        "rippleTarget": [{ type: Input, args: ["igxRippleTarget",] },],
        "rippleColor": [{ type: Input, args: ["igxRipple",] },],
        "rippleDuration": [{ type: Input, args: ["igxRippleDuration",] },],
        "centered": [{ type: Input, args: ["igxRippleCentered",] },],
        "onMouseDown": [{ type: HostListener, args: ["mousedown", ["$event"],] },],
    };
    return IgxRippleDirective;
}());
export { IgxRippleDirective };
var IgxRippleModule = /** @class */ (function () {
    function IgxRippleModule() {
    }
    IgxRippleModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxRippleDirective],
                    exports: [IgxRippleDirective]
                },] },
    ];
    /** @nocollapse */
    IgxRippleModule.ctorParameters = function () { return []; };
    return IgxRippleModule;
}());
export { IgxRippleModule };
//# sourceMappingURL=ripple.directive.js.map