import { Injectable } from "@angular/core";
import { Subject } from "rxjs/Subject";
import { SortingDirection } from "../data-operations/sorting-expression.interface";
var IgxGridAPIService = /** @class */ (function () {
    function IgxGridAPIService() {
        this.change = new Subject();
        this.state = new Map();
    }
    IgxGridAPIService.prototype.register = function (grid) {
        this.state.set(grid.id, grid);
    };
    IgxGridAPIService.prototype.get = function (id) {
        return this.state.get(id);
    };
    IgxGridAPIService.prototype.markForCheck = function (id) {
        this.get(id).cdr.markForCheck();
        if (this.get(id).rowList) {
            this.get(id).rowList.forEach(function (row) { return row.cdr.markForCheck(); });
        }
    };
    IgxGridAPIService.prototype.get_column_by_name = function (id, name) {
        return this.get(id).columnList.find(function (col) { return col.field === name; });
    };
    IgxGridAPIService.prototype.get_row = function (id, index) {
        return this.get(id).rowList.find(function (row) { return row.index === index; });
    };
    IgxGridAPIService.prototype.get_cell_by_field = function (id, rowIndex, field) {
        var row = this.get_row(id, rowIndex);
        if (row) {
            return row.cells.find(function (cell) { return cell.column.field === field; });
        }
    };
    IgxGridAPIService.prototype.get_cell_by_index = function (id, rowIndex, columnIndex) {
        var row = this.get_row(id, rowIndex);
        if (row) {
            return row.cells.find(function (cell) { return cell.columnIndex === columnIndex; });
        }
    };
    IgxGridAPIService.prototype.update = function (id, cell) {
        var index = this.get(id).data.indexOf(cell.row.rowData);
        this.get(id).data[index][cell.column.field] = cell.value;
    };
    IgxGridAPIService.prototype.updateRow = function (value, id, row) {
        var index = this.get(id).data.indexOf(row.rowData);
        this.get(id).data[index] = value;
    };
    IgxGridAPIService.prototype.sort = function (id, fieldName, dir) {
        var sortingState = this.get(id).sortingExpressions;
        this.prepare_sorting_expression(sortingState, fieldName, dir);
        this.get(id).sortingExpressions = sortingState;
    };
    IgxGridAPIService.prototype.sort_multiple = function (id, expressions) {
        var sortingState = this.get(id).sortingExpressions;
        for (var _i = 0, expressions_1 = expressions; _i < expressions_1.length; _i++) {
            var each = expressions_1[_i];
            this.prepare_sorting_expression(sortingState, each.fieldName, each.dir);
        }
        this.get(id).sortingExpressions = sortingState;
    };
    IgxGridAPIService.prototype.filter = function (id, fieldName, term, condition, ignoreCase) {
        var filteringState = this.get(id).filteringExpressions;
        if (this.get(id).paging) {
            this.get(id).page = 0;
        }
        this.prepare_filtering_expression(filteringState, fieldName, term, condition, ignoreCase);
        this.get(id).filteringExpressions = filteringState;
    };
    IgxGridAPIService.prototype.filterGlobal = function (id, term, condition, ignoreCase) {
        var filteringState = this.get(id).filteringExpressions;
        for (var _i = 0, _a = this.get(id).columns; _i < _a.length; _i++) {
            var column = _a[_i];
            this.prepare_filtering_expression(filteringState, column.field, term, condition || column.filteringCondition, ignoreCase || column.filteringIgnoreCase);
        }
        this.get(id).filteringExpressions = filteringState;
    };
    IgxGridAPIService.prototype.clear_filter = function (id, fieldName) {
        var filteringState = this.get(id).filteringExpressions;
        var index = filteringState.findIndex(function (expr) { return expr.fieldName === fieldName; });
        if (index > -1) {
            filteringState.splice(index, 1);
            this.get(id).filteringExpressions = filteringState;
        }
    };
    IgxGridAPIService.prototype.prepare_filtering_expression = function (state, fieldName, searchVal, condition, ignoreCase) {
        var expression = state.find(function (expr) { return expr.fieldName === fieldName; });
        var newExpression = { fieldName: fieldName, searchVal: searchVal, condition: condition, ignoreCase: ignoreCase };
        if (!expression) {
            state.push(newExpression);
        }
        else {
            Object.assign(expression, newExpression);
        }
    };
    IgxGridAPIService.prototype.prepare_sorting_expression = function (state, fieldName, dir) {
        if (dir === SortingDirection.None) {
            state.splice(state.findIndex(function (expr) { return expr.fieldName === fieldName; }), 1);
            return;
        }
        var expression = state.find(function (expr) { return expr.fieldName === fieldName; });
        if (!expression) {
            state.push({ fieldName: fieldName, dir: dir });
        }
        else {
            Object.assign(expression, { fieldName: fieldName, dir: dir });
        }
    };
    IgxGridAPIService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    IgxGridAPIService.ctorParameters = function () { return []; };
    return IgxGridAPIService;
}());
export { IgxGridAPIService };
//# sourceMappingURL=api.service.js.map