import { ChangeDetectionStrategy, ChangeDetectorRef, Component, ElementRef, HostBinding, HostListener, Input, TemplateRef, ViewChild } from "@angular/core";
import { DataType } from "../data-operations/data-util";
import { IgxGridAPIService } from "./api.service";
import { IgxColumnComponent } from "./column.component";
var IgxGridCellComponent = /** @class */ (function () {
    function IgxGridCellComponent(gridAPI, cdr, element) {
        this.gridAPI = gridAPI;
        this.cdr = cdr;
        this.element = element;
        this.tabindex = 0;
        this.role = "gridcell";
        this.defaultCssClass = "igx-grid__td";
        this.isFocused = false;
        this.isSelected = false;
        this._inEditMode = false;
    }
    Object.defineProperty(IgxGridCellComponent.prototype, "value", {
        get: function () {
            return this._value;
        },
        set: function (val) {
            this._value = val;
            this.gridAPI.update(this.gridID, this);
            this.cdr.markForCheck();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "formatter", {
        get: function () {
            return this.column.formatter;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "context", {
        get: function () {
            return {
                $implicit: this.value,
                cell: this
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "template", {
        get: function () {
            if (this.inEditMode) {
                var inlineEditorTemplate = this.column.inlineEditorTemplate;
                return inlineEditorTemplate ? inlineEditorTemplate : this.inlineEditorTemplate;
            }
            if (this.cellTemplate) {
                return this.cellTemplate;
            }
            return this.defaultCellTemplate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "gridID", {
        get: function () {
            return this.row.gridID;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "grid", {
        get: function () {
            return this.gridAPI.get(this.gridID);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "rowIndex", {
        get: function () {
            return this.row.index;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "columnIndex", {
        get: function () {
            return this.column.index;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "nativeElement", {
        get: function () {
            return this.element.nativeElement;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "inEditMode", {
        get: function () {
            return this._inEditMode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "readonly", {
        get: function () {
            return !this.column.editable;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "describedby", {
        get: function () {
            return this.row.gridID + "-" + this.column.field;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "styleClasses", {
        get: function () {
            return this.defaultCssClass + " " + this.column.cellClasses;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "width", {
        get: function () {
            return this.column.width;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "focused", {
        get: function () {
            return this.isFocused || this.isSelected;
        },
        set: function (val) {
            this.isFocused = val;
            this.cdr.markForCheck();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "applyNumberCSSClass", {
        get: function () {
            return this.column.dataType === DataType.Number;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridCellComponent.prototype, "selected", {
        get: function () {
            return this.isSelected;
        },
        set: function (val) {
            this.isSelected = val;
            this.cdr.markForCheck();
        },
        enumerable: true,
        configurable: true
    });
    IgxGridCellComponent.prototype.onDoubleClick = function (event) {
        if (this.column.editable) {
            this._inEditMode = true;
            this.grid.cellInEditMode = this;
        }
    };
    IgxGridCellComponent.prototype.onFocus = function (event) {
        this.isFocused = true;
        this.isSelected = true;
        this.row.focused = true;
        if (this.grid.cellInEditMode && this.grid.cellInEditMode !== this) {
            this.grid.cellInEditMode._inEditMode = false;
            this.grid.cellInEditMode.cdr.markForCheck();
            this.grid.cellInEditMode = null;
        }
        this.grid.onSelection.emit(this);
    };
    IgxGridCellComponent.prototype.onBlur = function (event) {
        this.isFocused = false;
        this.isSelected = false;
        this.row.focused = false;
    };
    IgxGridCellComponent.prototype.onKeyDown = function (event) {
        this.handleKeyboardNavigation(event);
        this.handleInlineEditMode(event);
    };
    IgxGridCellComponent.prototype.handleKeyboardNavigation = function (event) {
        var visibleColumns = this.grid.visibleColumns;
        var ri = this.rowIndex;
        var ci = this.columnIndex;
        var rv;
        var target;
        switch (event.keyCode) {
            case 37 /* LEFT_ARROW */:
                if (event.ctrlKey) {
                    ci = this.row.cells.first.columnIndex;
                    break;
                }
                rv = visibleColumns.findIndex(function (col) { return col.index === ci; });
                if (rv > 0) {
                    ci = visibleColumns[rv - 1].index;
                }
                break;
            case 38 /* UP_ARROW */:
                ri -= 1;
                break;
            case 39 /* RIGHT_ARROW */:
                if (event.ctrlKey) {
                    ci = this.row.cells.last.columnIndex;
                    break;
                }
                rv = visibleColumns.findIndex(function (col) { return col.index === ci; });
                if (rv > -1 && rv < visibleColumns.length - 1) {
                    ci = visibleColumns[rv + 1].index;
                }
                break;
            case 40 /* DOWN_ARROW */:
                ri += 1;
                break;
            default:
                return;
        }
        target = this.gridAPI.get_cell_by_index(this.gridID, ri, ci);
        if (target) {
            target.nativeElement.focus();
        }
    };
    IgxGridCellComponent.prototype.handleInlineEditMode = function (event) {
        if ((event.keyCode === 13 /* ENTER */ || event.keyCode === 113 /* F2 */) && this.column.editable) {
            this._inEditMode = !this._inEditMode;
            this.grid.cellInEditMode = this;
            return;
        }
        if (event.keyCode === 27 /* ESCAPE */) {
            this._inEditMode = false;
        }
    };
    IgxGridCellComponent.decorators = [
        { type: Component, args: [{
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    preserveWhitespaces: false,
                    selector: "igx-grid-cell",
                    template: "<ng-template #defaultCell>     {{ formatter ? formatter(value) : value }} </ng-template> <ng-template #inlineEditor let-cell=\"cell\">     <input igxInput [value]=\"value\" (keydown.enter)=\"cell.value = $event.target.value\"> </ng-template> <ng-container *ngTemplateOutlet=\"template; context: context\"> </ng-container>"
                },] },
    ];
    /** @nocollapse */
    IgxGridCellComponent.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
        { type: ChangeDetectorRef, },
        { type: ElementRef, },
    ]; };
    IgxGridCellComponent.propDecorators = {
        "column": [{ type: Input },],
        "row": [{ type: Input },],
        "cellTemplate": [{ type: Input },],
        "value": [{ type: Input },],
        "tabindex": [{ type: HostBinding, args: ["attr.tabindex",] },],
        "role": [{ type: HostBinding, args: ["attr.role",] },],
        "readonly": [{ type: HostBinding, args: ["attr.aria-readonly",] },],
        "describedby": [{ type: HostBinding, args: ["attr.aria-describedby",] },],
        "styleClasses": [{ type: HostBinding, args: ["class",] },],
        "width": [{ type: HostBinding, args: ["style.max-width",] },],
        "focused": [{ type: HostBinding, args: ["attr.aria-selected",] }, { type: HostBinding, args: ["class.igx-grid__td--selected",] },],
        "applyNumberCSSClass": [{ type: HostBinding, args: ["class.igx-grid__td--number",] },],
        "defaultCellTemplate": [{ type: ViewChild, args: ["defaultCell", { read: TemplateRef },] },],
        "inlineEditorTemplate": [{ type: ViewChild, args: ["inlineEditor", { read: TemplateRef },] },],
        "onDoubleClick": [{ type: HostListener, args: ["dblclick", ["$event"],] },],
        "onFocus": [{ type: HostListener, args: ["focus", ["$event"],] },],
        "onBlur": [{ type: HostListener, args: ["blur", ["$event"],] },],
        "onKeyDown": [{ type: HostListener, args: ["keydown", ["$event"],] },],
    };
    return IgxGridCellComponent;
}());
export { IgxGridCellComponent };
//# sourceMappingURL=cell.component.js.map