import { ChangeDetectionStrategy, ChangeDetectorRef, Component, ContentChild, Input } from "@angular/core";
import { DataType } from "../data-operations/data-util";
import { STRING_FILTERS } from "../data-operations/filtering-condition";
import { IgxGridAPIService } from "./api.service";
import { IgxCellFooterTemplateDirective, IgxCellHeaderTemplateDirective, IgxCellTemplateDirective } from "./grid.common";
var IgxColumnComponent = /** @class */ (function () {
    function IgxColumnComponent(gridAPI, cdr) {
        this.gridAPI = gridAPI;
        this.cdr = cdr;
        this.header = "";
        this.sortable = false;
        this.editable = false;
        this.filterable = false;
        this.movable = false;
        this.headerClasses = "";
        this.cellClasses = "";
        this.filteringCondition = STRING_FILTERS.contains;
        this.filteringIgnoreCase = true;
        this.dataType = DataType.String;
        this._hidden = false;
    }
    Object.defineProperty(IgxColumnComponent.prototype, "hidden", {
        get: function () {
            return this._hidden;
        },
        set: function (value) {
            this._hidden = value;
            this.check();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnComponent.prototype, "index", {
        get: function () {
            return this._index;
        },
        set: function (value) {
            this._index = value;
            this.check();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnComponent.prototype, "bodyTemplate", {
        get: function () {
            return this._bodyTemplate;
        },
        set: function (template) {
            this._bodyTemplate = template;
            this.gridAPI.markForCheck(this.gridID);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnComponent.prototype, "headerTemplate", {
        get: function () {
            return this._headerTemplate;
        },
        set: function (template) {
            this._headerTemplate = template;
            this.gridAPI.markForCheck(this.gridID);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnComponent.prototype, "footerTemplate", {
        get: function () {
            return this._headerTemplate;
        },
        set: function (template) {
            this._footerTemplate = template;
            this.gridAPI.markForCheck(this.gridID);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnComponent.prototype, "inlineEditorTemplate", {
        get: function () {
            return this._inlineEditorTemplate;
        },
        set: function (template) {
            this._inlineEditorTemplate = template;
            this.gridAPI.markForCheck(this.gridID);
        },
        enumerable: true,
        configurable: true
    });
    IgxColumnComponent.prototype.ngAfterContentInit = function () {
        if (this.cellTemplate) {
            this._bodyTemplate = this.cellTemplate.template;
        }
        if (this.headTemplate) {
            this._headerTemplate = this.headTemplate.template;
        }
        if (this.footTemplate) {
            this._footerTemplate = this.footTemplate.template;
        }
    };
    IgxColumnComponent.prototype.check = function () {
        if (this.gridID) {
            this.gridAPI.markForCheck(this.gridID);
        }
    };
    IgxColumnComponent.decorators = [
        { type: Component, args: [{
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    preserveWhitespaces: false,
                    selector: "igx-column",
                    template: ""
                },] },
    ];
    /** @nocollapse */
    IgxColumnComponent.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
        { type: ChangeDetectorRef, },
    ]; };
    IgxColumnComponent.propDecorators = {
        "field": [{ type: Input },],
        "header": [{ type: Input },],
        "sortable": [{ type: Input },],
        "editable": [{ type: Input },],
        "filterable": [{ type: Input },],
        "hidden": [{ type: Input },],
        "movable": [{ type: Input },],
        "width": [{ type: Input },],
        "headerClasses": [{ type: Input },],
        "cellClasses": [{ type: Input },],
        "index": [{ type: Input },],
        "formatter": [{ type: Input },],
        "filteringCondition": [{ type: Input },],
        "filteringIgnoreCase": [{ type: Input },],
        "dataType": [{ type: Input },],
        "cellTemplate": [{ type: ContentChild, args: [IgxCellTemplateDirective, { read: IgxCellTemplateDirective },] },],
        "headTemplate": [{ type: ContentChild, args: [IgxCellHeaderTemplateDirective, { read: IgxCellHeaderTemplateDirective },] },],
        "footTemplate": [{ type: ContentChild, args: [IgxCellFooterTemplateDirective, { read: IgxCellFooterTemplateDirective },] },],
    };
    return IgxColumnComponent;
}());
export { IgxColumnComponent };
//# sourceMappingURL=column.component.js.map