import { ChangeDetectionStrategy, ChangeDetectorRef, Component, ComponentFactoryResolver, ContentChildren, EventEmitter, HostBinding, Input, Output, QueryList, TemplateRef, ViewChildren, ViewContainerRef, ViewEncapsulation } from "@angular/core";
import { cloneArray } from "../core/utils";
import { DataType } from "../data-operations/data-util";
import { FilteringLogic } from "../data-operations/filtering-expression.interface";
import { SortingDirection } from "../data-operations/sorting-expression.interface";
import { IgxGridAPIService } from "./api.service";
import { IgxColumnComponent } from "./column.component";
import { IgxGridRowComponent } from "./row.component";
var NEXT_ID = 0;
var IgxGridComponent = /** @class */ (function () {
    function IgxGridComponent(gridAPI, cdr, resolver, viewRef) {
        this.gridAPI = gridAPI;
        this.cdr = cdr;
        this.resolver = resolver;
        this.viewRef = viewRef;
        this.data = [];
        this.autoGenerate = false;
        this.id = "igx-grid-" + NEXT_ID++;
        this.filteringLogic = FilteringLogic.And;
        this.evenRowCSS = "";
        this.oddRowCSS = "";
        this.onSelection = new EventEmitter();
        this.onColumnInit = new EventEmitter();
        this.onSorting = new EventEmitter();
        this.onFiltering = new EventEmitter();
        this.onPaging = new EventEmitter();
        this.onRowAdded = new EventEmitter();
        this.onRowDeleted = new EventEmitter();
        this.tabindex = 0;
        this.hostClass = "igx-grid";
        this.hostRole = "grid";
        this._perPage = 15;
        this._page = 0;
        this._paging = false;
        this._pipeTrigger = 0;
        this._columns = [];
        this._filteringLogic = FilteringLogic.And;
        this._filteringExpressions = [];
        this._sortingExpressions = [];
    }
    Object.defineProperty(IgxGridComponent.prototype, "filteringExpressions", {
        get: function () {
            return this._filteringExpressions;
        },
        set: function (value) {
            this._filteringExpressions = cloneArray(value);
            this.cdr.markForCheck();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "paging", {
        get: function () {
            return this._paging;
        },
        set: function (value) {
            this._paging = value;
            this._pipeTrigger++;
            this.cdr.markForCheck();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "page", {
        get: function () {
            return this._page;
        },
        set: function (val) {
            if (val < 0) {
                return;
            }
            this.onPaging.emit({ previous: this._page, current: val });
            this._page = val;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "perPage", {
        get: function () {
            return this._perPage;
        },
        set: function (val) {
            if (val < 0) {
                return;
            }
            this._perPage = val;
            this.page = 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "pipeTrigger", {
        get: function () {
            return this._pipeTrigger;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "sortingExpressions", {
        get: function () {
            return this._sortingExpressions;
        },
        set: function (value) {
            this._sortingExpressions = cloneArray(value);
            this.cdr.markForCheck();
        },
        enumerable: true,
        configurable: true
    });
    IgxGridComponent.prototype.ngOnInit = function () {
        this.gridAPI.register(this);
    };
    IgxGridComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        if (this.autoGenerate) {
            this.autogenerateColumns();
        }
        this.columnList.forEach(function (col, idx) {
            col.index = idx;
            col.gridID = _this.id;
            _this.onColumnInit.emit(col);
        });
        this._columns = this.columnList.toArray();
    };
    Object.defineProperty(IgxGridComponent.prototype, "columns", {
        get: function () {
            return this._columns;
        },
        enumerable: true,
        configurable: true
    });
    IgxGridComponent.prototype.getColumnByName = function (name) {
        return this.columnList.find(function (col) { return col.field === name; });
    };
    Object.defineProperty(IgxGridComponent.prototype, "visibleColumns", {
        get: function () {
            return this.columnList.filter(function (col) { return !col.hidden; }).sort(function (col1, col2) { return col1.index - col2.index; });
        },
        enumerable: true,
        configurable: true
    });
    IgxGridComponent.prototype.getCellByColumn = function (rowIndex, columnField) {
        return this.gridAPI.get_cell_by_field(this.id, rowIndex, columnField);
    };
    Object.defineProperty(IgxGridComponent.prototype, "totalPages", {
        get: function () {
            if (this.pagingState) {
                return this.pagingState.metadata.countPages;
            }
            return -1;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "totalRecords", {
        get: function () {
            if (this.pagingState) {
                return this.pagingState.metadata.countRecords;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "isFirstPage", {
        get: function () {
            return this.page === 0;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "isLastPage", {
        get: function () {
            return this.page + 1 >= this.totalPages;
        },
        enumerable: true,
        configurable: true
    });
    IgxGridComponent.prototype.nextPage = function () {
        if (!this.isLastPage) {
            this.page += 1;
        }
    };
    IgxGridComponent.prototype.previousPage = function () {
        if (!this.isFirstPage) {
            this.page -= 1;
        }
    };
    IgxGridComponent.prototype.paginate = function (val) {
        if (val < 0) {
            return;
        }
        this.page = val;
    };
    IgxGridComponent.prototype.markForCheck = function () {
        this.gridAPI.markForCheck(this.id);
    };
    IgxGridComponent.prototype.addRow = function (data) {
        this.data.push(data);
        this.onRowAdded.emit({ data: data });
        this._pipeTrigger++;
        this.cdr.markForCheck();
    };
    IgxGridComponent.prototype.deleteRow = function (rowIndex) {
        var row = this.gridAPI.get_row(this.id, rowIndex);
        if (row) {
            var index = this.data.indexOf(row.rowData);
            this.data.splice(index, 1);
            this.onRowDeleted.emit({ row: row });
            this._pipeTrigger++;
            this.cdr.markForCheck();
        }
    };
    IgxGridComponent.prototype.updateCell = function (value, rowIndex, column) {
        var cell = this.gridAPI.get_cell_by_field(this.id, rowIndex, column);
        if (cell) {
            cell.value = value;
            this._pipeTrigger++;
        }
    };
    IgxGridComponent.prototype.updateRow = function (value, rowIndex) {
        var row = this.gridAPI.get_row(this.id, rowIndex);
        if (row) {
            this.gridAPI.updateRow(value, this.id, row);
            this._pipeTrigger++;
            this.cdr.markForCheck();
        }
    };
    IgxGridComponent.prototype.sort = function (name, direction) {
        if (direction === void 0) { direction = SortingDirection.Asc; }
        this.gridAPI.sort(this.id, name, direction);
    };
    IgxGridComponent.prototype.sortMultiple = function (exprArray) {
        this.gridAPI.sort_multiple(this.id, exprArray);
    };
    IgxGridComponent.prototype.filter = function (name, value, condition, ignoreCase) {
        var col = this.gridAPI.get_column_by_name(this.id, name);
        if (!col) {
            return;
        }
        this.gridAPI.filter(this.id, name, value, condition || col.filteringCondition, ignoreCase || col.filteringIgnoreCase);
        this.page = 0;
    };
    IgxGridComponent.prototype.filterGlobal = function (value, condition, ignoreCase) {
        // TODO: AND OR Filtering logic
        this.gridAPI.filterGlobal(this.id, value, condition, ignoreCase);
        this.page = 0;
    };
    IgxGridComponent.prototype.clearFilter = function (name) {
        var col = this.gridAPI.get_column_by_name(this.id, name);
        if (!col) {
            return;
        }
        this.gridAPI.clear_filter(this.id, name);
    };
    IgxGridComponent.prototype.clearFilterAll = function () {
    };
    Object.defineProperty(IgxGridComponent.prototype, "hasSortableColumns", {
        get: function () {
            return this.columnList.some(function (col) { return col.sortable; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "hasEditableColumns", {
        get: function () {
            return this.columnList.some(function (col) { return col.editable; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "hasFilterableColumns", {
        get: function () {
            return this.columnList.some(function (col) { return col.filterable; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridComponent.prototype, "selectedCells", {
        get: function () {
            if (this.rowList) {
                return this.rowList.map(function (row) { return row.cells.filter(function (cell) { return cell.selected; }); })
                    .reduce(function (a, b) { return a.concat(b); }, []);
            }
            return [];
        },
        enumerable: true,
        configurable: true
    });
    IgxGridComponent.prototype.resolveDataTypes = function (rec) {
        if (typeof rec === "number") {
            return DataType.Number;
        }
        else if (typeof rec === "boolean") {
            return DataType.Boolean;
        }
        else if (typeof rec === "object" && rec instanceof Date) {
            return DataType.Date;
        }
        return DataType.String;
    };
    IgxGridComponent.prototype.autogenerateColumns = function () {
        var _this = this;
        var factory = this.resolver.resolveComponentFactory(IgxColumnComponent);
        var fields = Object.keys(this.data[0]);
        var columns = [];
        fields.forEach(function (field) {
            var ref = _this.viewRef.createComponent(factory);
            ref.instance.field = field;
            ref.instance.dataType = _this.resolveDataTypes(_this.data[0][field]);
            ref.changeDetectorRef.detectChanges();
            columns.push(ref.instance);
        });
        this.columnList.reset(columns);
    };
    IgxGridComponent.decorators = [
        { type: Component, args: [{
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    preserveWhitespaces: false,
                    selector: "igx-grid",
                    styles: [".igx-grid{display:-ms-grid;display:grid;-ms-grid-rows:min-content;grid-template-rows:-webkit-min-content;grid-template-rows:min-content;background:#fff;color:rgba(0,0,0,0.74);border-radius:.125em;-webkit-box-shadow:0 1px 5px 0 rgba(0,0,0,0.26),0 2px 2px 0 rgba(0,0,0,0.12),0 3px 1px -2px rgba(0,0,0,0.08);box-shadow:0 1px 5px 0 rgba(0,0,0,0.26),0 2px 2px 0 rgba(0,0,0,0.12),0 3px 1px -2px rgba(0,0,0,0.08);outline-style:none;overflow-x:auto}.igx-grid__caption{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;font-size:1.25em;line-height:2em;padding:1em 1.5em}.igx-grid__thead i{font-size:1rem}.igx-grid__thead,.igx-grid__tfoot{display:block;margin-right:16px}.igx-grid__thead .igx-grid__tr:hover,.igx-grid__tfoot .igx-grid__tr:hover{background-color:transparent}.igx-grid__tbody{position:relative;overflow-y:scroll;will-change:transform}.igx-grid__tbody-empty{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;text-align:center}.igx-grid__tr{display:-webkit-box;display:-ms-flexbox;display:flex;background:inherit;border-bottom:1px solid rgba(0,0,0,0.12);-webkit-transition:none;-o-transition:none;transition:none;outline-style:none}.igx-grid__tr:last-of-type{border-bottom:0}.igx-grid__tr:hover{background:rgba(0,0,0,0.04)}.igx-grid__tr--selected{color:#fff;background-color:rgba(0,0,0,0.74);border-bottom:1px solid transparent;-webkit-box-shadow:inset 0 3px 1px rgba(0,0,0,0.08);box-shadow:inset 0 3px 1px rgba(0,0,0,0.08)}.igx-grid__tr--selected:hover{background:rgba(0,0,0,0.74)}.igx-grid__th,.igx-grid__td{display:block;width:100%;outline-style:none;padding:1rem 1.5rem;font-size:.8125rem;line-height:1rem;color:inherit;text-align:left;overflow:hidden;white-space:nowrap;-o-text-overflow:ellipsis;text-overflow:ellipsis}.igx-grid__th--number,.igx-grid__td--number{text-align:right}.igx-grid__td--selected{color:#fff;background-color:#e41c77 !important;border-bottom:0;margin-bottom:-1px;-webkit-box-shadow:inset 0 3px 1px rgba(0,0,0,0.12);box-shadow:inset 0 3px 1px rgba(0,0,0,0.12);z-index:10}.igx-grid__th{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;font-size:.75em;font-weight:600;overflow:visible;min-width:0}.igx-grid__th .title{cursor:pointer;overflow:hidden;white-space:nowrap;-o-text-overflow:ellipsis;text-overflow:ellipsis;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.igx-grid__th.asc,.igx-grid__th.desc{font-weight:800}.igx-grid__th.desc>.title::before{position:relative;font-family:'Material Icons';content:'\\E5DB';margin-right:8px}.igx-grid__th.asc>.title::before{position:relative;font-family:'Material Icons';content:'\\E5D8';margin-right:8px}"],
                    template: "<ng-template #defaultPager let-api>     <div *ngIf=\"api.paging && api.totalPages > 0\" class=\"igx-paginator\">         <button [disabled]=\"api.isFirstPage\" (click)=\"api.paginate(0)\" igxButton=\"icon\" igxRipple igxRippleCentered=\"true\">             <igx-icon fontSet=\"material\" name=\"first_page\"></igx-icon>         </button>         <button [disabled]=\"api.isFirstPage\" (click)=\"api.previousPage()\" igxButton=\"icon\" igxRipple igxRippleCentered=\"true\">             <igx-icon fontSet=\"material\" name=\"chevron_left\"></igx-icon>         </button>         <span>{{ api.page + 1 }} of {{ api.totalPages }}</span>         <button [disabled]=\"api.isLastPage\" (click)=\"api.nextPage()\" igxRipple igxRippleCentered=\"true\" igxButton=\"icon\">             <igx-icon fontSet=\"material\" name=\"chevron_right\"></igx-icon>         </button>         <button [disabled]=\"api.isLastPage\" (click)=\"api.paginate(api.totalPages - 1)\" igxButton=\"icon\" igxRipple igxRippleCentered=\"true\">             <igx-icon fontSet=\"material\" name=\"last_page\"></igx-icon>         </button>         <select style=\"margin-left: 1rem;\" (change)=\"api.perPage = $event.target.value\">             <option [value]=\"val\" [selected]=\"api.perPage == val\" *ngFor=\"let val of [5, 10, 15, 25, 50, 100, 500]\">{{ val }}</option>         </select>     </div> </ng-template>   <div class=\"igx-grid__thead\">     <div class=\"igx-grid__tr\" role=\"row\">         <igx-grid-header [gridID]=\"id\" *ngFor=\"let col of visibleColumns\" [column]=\"col\"></igx-grid-header>     </div> </div>  <div class=\"igx-grid__tbody\">     <igx-grid-row [gridID]=\"id\" [index]=\"i\" [rowData]=\"item\" *ngFor=\"let item of data | gridFiltering:filteringExpressions:filteringLogic:id:pipeTrigger                                  | gridSort:sortingExpressions:id:pipeTrigger                                  | gridPaging:page:perPage:id:pipeTrigger;                                  index as i;\">     </igx-grid-row> </div>  <div class=\"igx-grid__tfoot\">     <ng-container *ngTemplateOutlet=\"paginationTemplate ? paginationTemplate : defaultPager; context: { $implicit: this }\">     </ng-container> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxGridComponent.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
        { type: ChangeDetectorRef, },
        { type: ComponentFactoryResolver, },
        { type: ViewContainerRef, },
    ]; };
    IgxGridComponent.propDecorators = {
        "data": [{ type: Input },],
        "autoGenerate": [{ type: Input },],
        "id": [{ type: Input },],
        "filteringLogic": [{ type: Input },],
        "filteringExpressions": [{ type: Input },],
        "paging": [{ type: Input },],
        "page": [{ type: Input },],
        "perPage": [{ type: Input },],
        "paginationTemplate": [{ type: Input },],
        "height": [{ type: HostBinding, args: ["style.height",] }, { type: Input },],
        "width": [{ type: HostBinding, args: ["style.width",] }, { type: Input },],
        "evenRowCSS": [{ type: Input },],
        "oddRowCSS": [{ type: Input },],
        "onSelection": [{ type: Output },],
        "onColumnInit": [{ type: Output },],
        "onSorting": [{ type: Output },],
        "onFiltering": [{ type: Output },],
        "onPaging": [{ type: Output },],
        "onRowAdded": [{ type: Output },],
        "onRowDeleted": [{ type: Output },],
        "columnList": [{ type: ContentChildren, args: [IgxColumnComponent, { read: IgxColumnComponent },] },],
        "rowList": [{ type: ViewChildren, args: [IgxGridRowComponent, { read: IgxGridRowComponent },] },],
        "tabindex": [{ type: HostBinding, args: ["attr.tabindex",] },],
        "hostClass": [{ type: HostBinding, args: ["attr.class",] },],
        "hostRole": [{ type: HostBinding, args: ["attr.role",] },],
        "sortingExpressions": [{ type: Input },],
    };
    return IgxGridComponent;
}());
export { IgxGridComponent };
//# sourceMappingURL=grid.component.js.map