import { ChangeDetectionStrategy, ChangeDetectorRef, Component, forwardRef, HostBinding, HostListener, Input, QueryList, ViewChildren } from "@angular/core";
import { IgxGridAPIService } from "./api.service";
import { IgxGridCellComponent } from "./cell.component";
var IgxGridRowComponent = /** @class */ (function () {
    function IgxGridRowComponent(gridAPI, cdr) {
        this.gridAPI = gridAPI;
        this.cdr = cdr;
        this.tabindex = 0;
        this.role = "row";
        this.defaultCssClass = "igx-grid__tr";
        this.isFocused = false;
    }
    Object.defineProperty(IgxGridRowComponent.prototype, "styleClasses", {
        get: function () {
            return this.defaultCssClass + " " + (this.index % 2 ? this.grid.evenRowCSS : this.grid.oddRowCSS);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridRowComponent.prototype, "focused", {
        get: function () {
            return this.isFocused;
        },
        set: function (val) {
            this.isFocused = val;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridRowComponent.prototype, "columns", {
        get: function () {
            return this.grid.visibleColumns;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxGridRowComponent.prototype, "grid", {
        get: function () {
            return this.gridAPI.get(this.gridID);
        },
        enumerable: true,
        configurable: true
    });
    IgxGridRowComponent.prototype.onFocus = function (event) {
        this.isFocused = true;
        // TODO: Emit selection event
    };
    IgxGridRowComponent.prototype.onBlur = function (event) {
        this.isFocused = false;
        // TODO: Emit de-selection event
    };
    IgxGridRowComponent.decorators = [
        { type: Component, args: [{
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    preserveWhitespaces: false,
                    selector: "igx-grid-row",
                    template: "<igx-grid-cell *ngFor=\"let c of columns\" [column]=\"c\" [row]=\"this\" [value]=\"rowData[c.field]\" [cellTemplate]=\"c.bodyTemplate\"></igx-grid-cell>"
                },] },
    ];
    /** @nocollapse */
    IgxGridRowComponent.ctorParameters = function () { return [
        { type: IgxGridAPIService, },
        { type: ChangeDetectorRef, },
    ]; };
    IgxGridRowComponent.propDecorators = {
        "rowData": [{ type: Input },],
        "index": [{ type: Input },],
        "gridID": [{ type: Input },],
        "cells": [{ type: ViewChildren, args: [forwardRef(function () { return IgxGridCellComponent; }), { read: IgxGridCellComponent },] },],
        "tabindex": [{ type: HostBinding, args: ["attr.tabindex",] },],
        "role": [{ type: HostBinding, args: ["attr.role",] },],
        "styleClasses": [{ type: HostBinding, args: ["class",] },],
        "focused": [{ type: HostBinding, args: ["attr.aria-selected",] }, { type: HostBinding, args: ["class.igx-grid__tr--selected",] },],
        "onFocus": [{ type: HostListener, args: ["focus", ["$event"],] },],
        "onBlur": [{ type: HostListener, args: ["blur", ["$event"],] },],
    };
    return IgxGridRowComponent;
}());
export { IgxGridRowComponent };
//# sourceMappingURL=row.component.js.map