import { CommonModule } from "@angular/common";
import { Component, ContentChildren, ElementRef, EventEmitter, forwardRef, Input, NgModule, Output, QueryList, ViewChildren, ViewEncapsulation } from "@angular/core";
import { IgxBadgeModule } from "../badge/badge.component";
import { IgxIconModule } from "../icon/icon.component";
var IgxTabBar = /** @class */ (function () {
    function IgxTabBar(_element) {
        this._element = _element;
        this.onTabSelected = new EventEmitter();
        this.onTabDeselected = new EventEmitter();
        this.selectedIndex = -1;
        this._itemStyle = "igx-tab-bar";
    }
    Object.defineProperty(IgxTabBar.prototype, "itemStyle", {
        get: function () {
            return this._itemStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxTabBar.prototype, "selectedTab", {
        get: function () {
            if (this.tabs && this.selectedIndex !== undefined) {
                return this.tabs.toArray()[this.selectedIndex];
            }
        },
        enumerable: true,
        configurable: true
    });
    IgxTabBar.prototype.ngAfterViewInit = function () {
        var _this = this;
        // initial selection
        setTimeout(function () {
            if (_this.selectedIndex === -1) {
                var selectablePanels = _this.panels.filter(function (p) { return !p.isDisabled; });
                var panel = selectablePanels[0];
                if (panel) {
                    panel.select();
                }
            }
        }, 0);
    };
    IgxTabBar.prototype._selectedPanelHandler = function (args) {
        var _this = this;
        this.selectedIndex = args.panel.index;
        this.panels.forEach(function (p) {
            if (p.index !== _this.selectedIndex) {
                _this._deselectPanel(p);
            }
        });
    };
    IgxTabBar.prototype._deselectPanel = function (panel) {
        // Cannot deselect the selected tab - this will mean that there will be not selected tab left
        if (panel.isDisabled || this.selectedTab.index === panel.index) {
            return;
        }
        panel.isSelected = false;
        this.onTabDeselected.emit({ tab: this.tabs[panel.index], panel: panel });
    };
    IgxTabBar.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    host: {
                        "(onTabSelected)": "_selectedPanelHandler($event)"
                    },
                    selector: "igx-tab-bar",
                    styles: [".igx-tab-bar__panel,.igx-tab-bar__panel--selected{display:none}.igx-tab-bar__panel--selected{display:block}.igx-tab-bar__menu,.igx-tab-bar__menu--top,.igx-tab-bar__menu--bottom{display:-webkit-box;display:-ms-flexbox;display:flex;position:fixed;width:100%;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:3.5em;background:#fff;color:#333;overflow:hidden;z-index:8}.igx-tab-bar__menu--top{bottom:inherit;top:0;-webkit-box-shadow:0 5px 5px -3px rgba(0,0,0,0.26),0 8px 10px 1px rgba(0,0,0,0.12),0 3px 14px 2px rgba(0,0,0,0.08);box-shadow:0 5px 5px -3px rgba(0,0,0,0.26),0 8px 10px 1px rgba(0,0,0,0.12),0 3px 14px 2px rgba(0,0,0,0.08)}.igx-tab-bar__menu--bottom{top:inherit;bottom:0;-webkit-box-shadow:0 -2px 4px -1px rgba(0,0,0,0.26),0 -4px 5px 0 rgba(0,0,0,0.12),0 -1px 10px 0 rgba(0,0,0,0.08);box-shadow:0 -2px 4px -1px rgba(0,0,0,0.26),0 -4px 5px 0 rgba(0,0,0,0.12),0 -1px 10px 0 rgba(0,0,0,0.08)}.igx-tab-bar__menu-item{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;min-width:80px;max-width:168px;height:100%;-webkit-box-flex:1;-ms-flex:1;flex:1;cursor:pointer;text-transform:uppercase;white-space:nowrap;-o-text-overflow:ellipsis;text-overflow:ellipsis;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;overflow:hidden;padding:0 .75em;-webkit-tap-highlight-color:transparent}.igx-tab-bar__menu-item--disabled{opacity:.5;cursor:default}.igx-tab-bar__menu-item--selected .tab-label,.igx-tab-bar__menu-item--selected .tab-icon{opacity:1;color:#0375be;-webkit-transition:color .25s ease-out, opacity .25s ease-out;-o-transition:color .25s ease-out, opacity .25s ease-out;transition:color .25s ease-out, opacity .25s ease-out}.igx-tab-bar__menu-item .tab-label{padding-top:5px;font-size:.75em;line-height:.75em;max-width:80px;text-transform:uppercase;-o-text-overflow:ellipsis;text-overflow:ellipsis;overflow:hidden;z-index:1;opacity:.75}.igx-tab-bar__menu-item .tab-icon{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;height:24px;z-index:1;opacity:.75;padding:0 8px}.igx-tab-bar__menu-item .tab-icon i{width:24px;height:24px}"],
                    template: "<div>     <ng-content></ng-content> </div> <div #tablist class=\"{{itemStyle}}__menu {{itemStyle}}__menu--bottom\" role=\"tablist\" aria-orientation=\"horizontal\">     <igx-tab *ngFor=\"let panel of panels\"              [id]=\"'igx-tab-' + panel.index\"              [attr.aria-label]= \"panel.label\"              [attr.aria-disabled]=\"panel.isDisabled\"              [attr.aria-selected]=\"panel.isSelected\"              [attr.aria-controls]=\"'igx-tab-panel-'+ panel.index\"              [class.igx-tab-bar__menu-item--selected]=\"panel.isSelected\"              [class.igx-tab-bar__menu-item--disabled]=\"panel.isDisabled\"              [relatedPanel]=\"panel\"              (click)= \"panel.select()\"              role=\"tab\" >     </igx-tab> </div>"
                },] },
    ];
    /** @nocollapse */
    IgxTabBar.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    IgxTabBar.propDecorators = {
        "tabs": [{ type: ViewChildren, args: [forwardRef(function () { return IgxTab; }),] },],
        "panels": [{ type: ContentChildren, args: [forwardRef(function () { return IgxTabPanel; }),] },],
        "onTabSelected": [{ type: Output },],
        "onTabDeselected": [{ type: Output },],
    };
    return IgxTabBar;
}());
export { IgxTabBar };
// ================================= IgxTabPanel ======================================
var IgxTabPanel = /** @class */ (function () {
    function IgxTabPanel(_tabBar) {
        this._tabBar = _tabBar;
        this.isSelected = false;
        this._itemStyle = "igx-tab-panel";
    }
    Object.defineProperty(IgxTabPanel.prototype, "itemStyle", {
        get: function () {
            return this._itemStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxTabPanel.prototype, "relatedTab", {
        get: function () {
            if (this._tabBar.tabs) {
                return this._tabBar.tabs.toArray()[this.index];
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxTabPanel.prototype, "index", {
        get: function () {
            return this._tabBar.panels.toArray().indexOf(this);
        },
        enumerable: true,
        configurable: true
    });
    IgxTabPanel.prototype.select = function () {
        if (this.isDisabled || this._tabBar.selectedIndex === this.index) {
            return;
        }
        this.isSelected = true;
        this._tabBar.onTabSelected.emit({ tab: this._tabBar.tabs.toArray()[this.index], panel: this });
    };
    IgxTabPanel.decorators = [
        { type: Component, args: [{
                    host: {
                        "[attr.aria-labelledby]": "'igx-tab-' + index",
                        "[class.igx-tab-bar__panel--selected]": "isSelected",
                        "[class.igx-tab-bar__panel]": "!isSelected",
                        "[id]": "'igx-tab-bar__panel-' + index",
                        "role": "tabpanel"
                    },
                    selector: "igx-tab-panel",
                    template: "<ng-content></ng-content>"
                },] },
    ];
    /** @nocollapse */
    IgxTabPanel.ctorParameters = function () { return [
        { type: IgxTabBar, },
    ]; };
    IgxTabPanel.propDecorators = {
        "label": [{ type: Input },],
        "icon": [{ type: Input },],
        "isDisabled": [{ type: Input },],
    };
    return IgxTabPanel;
}());
export { IgxTabPanel };
// ======================================= IgxTab ==========================================
var IgxTab = /** @class */ (function () {
    function IgxTab(_tabBar, _element) {
        this._tabBar = _tabBar;
        this._element = _element;
        this._changesCount = 0;
    }
    Object.defineProperty(IgxTab.prototype, "changesCount", {
        get: function () {
            return this._changesCount;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxTab.prototype, "isDisabled", {
        get: function () {
            var panel = this.relatedPanel;
            if (panel) {
                return panel.isDisabled;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxTab.prototype, "isSelected", {
        get: function () {
            var panel = this.relatedPanel;
            if (panel) {
                return panel.isSelected;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxTab.prototype, "index", {
        get: function () {
            return this._tabBar.tabs.toArray().indexOf(this);
        },
        enumerable: true,
        configurable: true
    });
    IgxTab.prototype.select = function () {
        this.relatedPanel.select();
    };
    IgxTab.decorators = [
        { type: Component, args: [{
                    host: {
                        class: "igx-tab-bar__menu-item",
                        role: "tab"
                    },
                    selector: "igx-tab",
                    template: "<div *ngIf=\"relatedPanel.icon\" ngClass=\"tab-icon\">     <igx-icon fontSet=\"material\" [name]=\"relatedPanel.icon\"></igx-icon>     <igx-badge [value]=\"changesCount\" [hidden]=\"changesCount == 0\"></igx-badge> </div> <div *ngIf=\"relatedPanel.label\" ngClass=\"tab-label\">{{relatedPanel.label}}</div>"
                },] },
    ];
    /** @nocollapse */
    IgxTab.ctorParameters = function () { return [
        { type: IgxTabBar, },
        { type: ElementRef, },
    ]; };
    IgxTab.propDecorators = {
        "relatedPanel": [{ type: Input },],
    };
    return IgxTab;
}());
export { IgxTab };
var IgxTabBarModule = /** @class */ (function () {
    function IgxTabBarModule() {
    }
    IgxTabBarModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxTabBar, IgxTabPanel, IgxTab],
                    exports: [IgxTabBar, IgxTabPanel, IgxTab],
                    imports: [CommonModule, IgxBadgeModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxTabBarModule.ctorParameters = function () { return []; };
    return IgxTabBarModule;
}());
export { IgxTabBarModule };
//# sourceMappingURL=tabbar.component.js.map