import { EventEmitter } from "@angular/core";
/**
 * IgxToast provides information and warning messages. They could not be dismissed, are non-interactive and can appear
 * on top, middle and the bottom of the screen.
 * ```
 * <igx-toast (event output bindings) [input bindings]>
 * </igx-toast>
 * ```
 */
export declare class IgxToast {
    readonly CSS_CLASSES: {
        IGX_TOAST_BOTTOM: string;
        IGX_TOAST_MIDDLE: string;
        IGX_TOAST_TOP: string;
    };
    /**
     * Event is thrown prior toast is shown
     * @type {EventEmitter}
     */
    onShowing: EventEmitter<{}>;
    /**
     * Event is shown when toast is shown
     * @type {EventEmitter}
     */
    onShown: EventEmitter<{}>;
    /**
     * Event is thrown prior toast hidden
     * @type {EventEmitter}
     */
    onHiding: EventEmitter<{}>;
    /**
     * Event is thrown when toast hidden
     * @type {EventEmitter}
     */
    onHidden: EventEmitter<{}>;
    /**
     * Sets if the IgxToast component will be hidden after shown
     * Default value is true
     * @type {number}
     */
    autoHide: boolean;
    /**
     * The duration of time span in ms which the IgxToast component will be visible
     * after it is being shown.
     * Default value is 4000
     * @type {number}
     */
    displayTime: number;
    /**
     * The IgxToast component visual state state
     * @type {boolean}
     */
    isVisible: boolean;
    /**
     * The message that will be shown message by the IgxToast component
     * @type {string}
     */
    message: string;
    /**
     * Specifies the position of the IgxToast component. Possible options are IgxToastPosition.Top,
     * IgxToastPosition.Middle, IgxToastPosition.Bottom
     * @type {IgxToastPosition}
     */
    position: IgxToastPosition;
    private timeoutId;
    /**
     * Shows the IgxToast component and hides it after some time span
     * if autoHide is enabled
     */
    show(): void;
    /**
     * Hides the IgxToast component
     */
    hide(): void;
    mapPositionToClassName(): any;
}
/**
 * Enumeration for toast position
 * Can be:
 * Bottom
 * Middle
 * Top
 */
export declare enum IgxToastPosition {
    Bottom = 0,
    Middle = 1,
    Top = 2,
}
export declare class IgxToastModule {
}
